@@ -48,11 +48,8 @@ class StockDataScraper:
             end_year = search_range['end_year']
             end_month = search_range['end_month']
             end_day = search_range['end_day']
-            # datetimeに入力して比較しようとすると ValueError: day is out of range for month が出るので迂回した
-            end_datetime = datetime.strptime(f'{end_year}{end_month}{end_day}', '%Y%m%d')
-            if dt_now < end_datetime:
+            if dt_now < datetime(end_year, end_month, end_day):
                 raise ValueError(f'検索範囲終了時点を未来にできない．{dt_now.year}/{dt_now.month}/{dt_now.day}以前に指定せよ！')
-            """
         
         # データ収集
         endofdata_flag = False
